@@ -1,4 +1,4 @@
-# Copyright 2013 - Mirantis, Inc.
+# Copyright 2015 - Mirantis, Inc.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License");
 #    you may not use this file except in compliance with the License.
@@ -12,12 +12,10 @@
 #    See the License for the specific language governing permissions and
 #    limitations under the License.
 
-from oslo.config import cfg
+import json
 
-from mistral import context
 from mistral.db.v2 import api as db_api
 from mistral import exceptions as exc
-from mistral.services import trusts
 from mistral.workbook import parser as spec_parser
 
 
@@ -40,21 +38,25 @@ def update_actions(definition, scope='private'):
 
     with db_api.transaction():
         for action_spec in action_list_spec.get_actions():
-            db_actions.append(create_or_update_action(action_spec,
-                                                      definition,
-                                                      scope))
+            db_actions.append(
+                create_or_update_action(
+                    action_spec,
+                    definition,
+                    scope
+                )
+            )
 
     return db_actions
 
 
 def create_action(action_spec, definition, scope):
-    return db_api.create_action(
+    return db_api.create_action_definition(
         _get_action_values(action_spec, definition, scope)
     )
 
 
 def create_or_update_action(action_spec, definition, scope):
-    action = db_api.load_action(action_spec.get_name())
+    action = db_api.load_action_definition(action_spec.get_name())
 
     if action and action.is_system:
         raise exc.InvalidActionException(
@@ -64,10 +66,26 @@ def create_or_update_action(action_spec, definition, scope):
 
     values = _get_action_values(action_spec, definition, scope)
 
-    return db_api.create_or_update_action(values['name'], values)
+    return db_api.create_or_update_action_definition(values['name'], values)
+
+
+def get_input_list(action_input):
+    input_list = []
+
+    for param in action_input:
+        if isinstance(param, dict):
+            for k, v in param.items():
+                input_list.append("%s=%s" % (k, json.dumps(v)))
+        else:
+            input_list.append(param)
+
+    return input_list
 
 
 def _get_action_values(action_spec, definition, scope):
+    action_input = action_spec.to_dict().get('input', [])
+    input_list = get_input_list(action_input)
+
     values = {
         'name': action_spec.get_name(),
         'description': action_spec.get_description(),
@@ -75,18 +93,8 @@ def _get_action_values(action_spec, definition, scope):
         'definition': definition,
         'spec': action_spec.to_dict(),
         'is_system': False,
-        'input': ", ".join(action_spec.get_input()),
+        'input': ", ".join(input_list) if input_list else None,
         'scope': scope
     }
 
-    _add_security_info(values)
-
     return values
-
-
-def _add_security_info(values):
-    if cfg.CONF.pecan.auth_enable and not values['name'].startswith('std.'):
-        values.update({
-            'trust_id': trusts.create_trust().id,
-            'project_id': context.ctx().project_id
-        })
