@@ -1,6 +1,5 @@
-# -*- coding: utf-8 -*-
-#
 # Copyright 2013 - Mirantis, Inc.
+# Copyright 2015 - StackStorm, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 #    you may not use this file except in compliance with the License.
@@ -14,62 +13,88 @@
 #    See the License for the specific language governing permissions and
 #    limitations under the License.
 
+import datetime
+import json
 import pkg_resources as pkg
 import sys
 import time
 
-from oslo.config import cfg
-from oslo import messaging
-from oslo.messaging import transport
+import mock
+from oslo_config import cfg
+from oslo_log import log as logging
 from oslotest import base
-from stevedore import driver
+import six
 import testtools.matchers as ttm
 
 from mistral import context as auth_context
 from mistral.db.sqlalchemy import base as db_sa_base
-from mistral.db.v1 import api as db_api_v1
+from mistral.db.sqlalchemy import sqlite_lock
 from mistral.db.v2 import api as db_api_v2
-from mistral import engine
-from mistral.engine import executor
-from mistral.openstack.common import log as logging
 from mistral.services import action_manager
+from mistral.services import security
+from mistral.tests import config as test_config
+from mistral.utils import inspect_utils as i_utils
 from mistral import version
 
+
 RESOURCES_PATH = 'tests/resources/'
 LOG = logging.getLogger(__name__)
 
 
+test_config.parse_args()
+
+
 def get_resource(resource_name):
     return open(pkg.resource_filename(
         version.version_info.package,
         RESOURCES_PATH + resource_name)).read()
 
 
-# TODO(rakhmerov): Remove together with the current engine implementation.
-def get_fake_transport():
-    # Get transport here to let oslo.messaging setup default config
-    # before changing the rpc_backend to the fake driver; otherwise,
-    # oslo.messaging will throw exception.
-    messaging.get_transport(cfg.CONF)
+def get_context(default=True, admin=False):
+    if default:
+        return auth_context.MistralContext(
+            user_id='1-2-3-4',
+            project_id=security.DEFAULT_PROJECT_ID,
+            user_name='test-user',
+            project_name='test-project',
+            is_admin=admin
+        )
+    else:
+        return auth_context.MistralContext(
+            user_id='9-0-44-5',
+            project_id='99-88-33',
+            user_name='test-user',
+            project_name='test-another',
+            is_admin=admin
+        )
 
-    cfg.CONF.set_default('rpc_backend', 'fake')
 
-    url = transport.TransportURL.parse(cfg.CONF, None, None)
-
-    kwargs = dict(
-        default_exchange=cfg.CONF.control_exchange,
-        allowed_remote_exmods=[]
+def register_action_class(name, cls, attributes=None, desc=None):
+    action_manager.register_action_class(
+        name,
+        '%s.%s' % (cls.__module__, cls.__name__),
+        attributes or {},
+        input_str=i_utils.get_arg_list_as_str(cls.__init__)
     )
 
-    mgr = driver.DriverManager(
-        'oslo.messaging.drivers',
-        url.transport,
-        invoke_on_load=True,
-        invoke_args=[cfg.CONF, url],
-        invoke_kwds=kwargs
-    )
 
-    return transport.Transport(mgr.driver)
+class FakeHTTPResponse(object):
+    def __init__(self, text, status_code, reason=None, headers=None,
+                 history=None, encoding='utf8', url='', cookies=None,
+                 elapsed=None):
+        self.text = text
+        self.content = text
+        self.status_code = status_code
+        self.reason = reason
+        self.headers = headers or {}
+        self.history = history
+        self.encoding = encoding
+        self.url = url
+        self.cookies = cookies or {}
+        self.elapsed = elapsed or datetime.timedelta(milliseconds=123)
+
+    def json(self):
+        return json.loads(self.text)
 
 
 class BaseTest(base.BaseTestCase):
@@ -92,16 +117,18 @@ class BaseTest(base.BaseTestCase):
 
     def _assert_multiple_items(self, items, count, **props):
         def _matches(item, **props):
-            for prop_name, prop_val in props.iteritems():
-                v = item[prop_name] if isinstance(item, dict) \
-                    else getattr(item, prop_name)
+            for prop_name, prop_val in six.iteritems(props):
+                v = item[prop_name] if isinstance(
+                    item, dict) else getattr(item, prop_name)
 
                 if v != prop_val:
                     return False
 
             return True
 
-        filtered_items = filter(lambda item: _matches(item, **props), items)
+        filtered_items = list(
+            filter(lambda item: _matches(item, **props), items)
+        )
 
         found = len(filtered_items)
 
@@ -123,7 +150,7 @@ class BaseTest(base.BaseTestCase):
         missing = []
         mismatched = []
 
-        for key, value in expected.iteritems():
+        for key, value in six.iteritems(expected):
             if key not in actual:
                 missing.append(key)
             elif value != actual[key]:
@@ -145,7 +172,7 @@ class BaseTest(base.BaseTestCase):
 
         self.fail(self._formatMessage(msg, standardMsg))
 
-    def _await(self, predicate, delay=1, timeout=30):
+    def _await(self, predicate, delay=1, timeout=60):
         """Awaits for predicate function to evaluate to True.
 
         If within a configured timeout predicate function hasn't evaluated
@@ -191,42 +218,46 @@ class DbTestCase(BaseTest):
         """Runs a long initialization (runs once by class)
         and can be extended by child classes.
         """
-        cfg.CONF.set_default('connection', 'sqlite://', group='database')
+        # If using sqlite, change to memory. The default is file based.
+        if cfg.CONF.database.connection.startswith('sqlite'):
+            cfg.CONF.set_default('connection', 'sqlite://', group='database')
+
         cfg.CONF.set_default('max_overflow', -1, group='database')
         cfg.CONF.set_default('max_pool_size', 1000, group='database')
 
-        db_api_v1.setup_db()
         db_api_v2.setup_db()
 
         action_manager.sync_db()
 
     def _clean_db(self):
-        with db_api_v1.transaction():
-            db_api_v1.workbooks_delete()
-            db_api_v1.executions_delete()
-            db_api_v1.triggers_delete()
-            db_api_v1.tasks_delete()
+        contexts = [
+            get_context(default=False),
+            get_context(default=True)
+        ]
 
-        with db_api_v2.transaction():
-            db_api_v2.delete_workbooks()
-            db_api_v2.delete_tasks()
-            db_api_v2.delete_executions()
-            db_api_v2.delete_cron_triggers()
-            db_api_v2.delete_workflows()
+        for ctx in contexts:
+            auth_context.set_ctx(ctx)
+
+            with mock.patch('mistral.services.security.get_project_id',
+                            new=mock.MagicMock(return_value=ctx.project_id)):
+                with db_api_v2.transaction():
+                    db_api_v2.delete_executions()
+                    db_api_v2.delete_workbooks()
+                    db_api_v2.delete_cron_triggers()
+                    db_api_v2.delete_workflow_definitions()
+                    db_api_v2.delete_environments()
+
+        sqlite_lock.cleanup()
+
+        if not cfg.CONF.database.connection.startswith('sqlite'):
+            db_sa_base.get_engine().dispose()
 
     def setUp(self):
         super(DbTestCase, self).setUp()
 
         self.__heavy_init()
 
-        self.ctx = auth_context.MistralContext(
-            user_id='1-2-3-4',
-            project_id='5-6-7-8',
-            user_name='test-user',
-            project_name='test-project',
-            is_admin=False
-        )
-
+        self.ctx = get_context()
         auth_context.set_ctx(self.ctx)
 
         self.addCleanup(auth_context.set_ctx, None)
@@ -234,76 +265,3 @@ class DbTestCase(BaseTest):
 
     def is_db_session_open(self):
         return db_sa_base._get_thread_local_session() is not None
-
-
-# TODO(rakhmerov): Remove together with the current engine implementation.
-class EngineTestCase(DbTestCase):
-    transport = get_fake_transport()
-    backend = engine.get_engine(cfg.CONF.engine.engine, transport)
-
-    def __init__(self, *args, **kwargs):
-        super(EngineTestCase, self).__init__(*args, **kwargs)
-
-        self.engine = engine.EngineClient(self.transport)
-
-    @classmethod
-    def mock_task_result(cls, task_id, state, result):
-        """Mock the engine convey_task_results to send request directly
-        to the engine instead of going through the oslo.messaging transport.
-        """
-        kwargs = {
-            'task_id': task_id,
-            'state': state,
-            'result': result
-        }
-
-        return cls.backend.convey_task_result({}, **kwargs)
-
-    @classmethod
-    def mock_start_workflow(cls, workbook_name, task_name, context=None):
-        """Mock the engine start_workflow_execution to send request directly
-        to the engine instead of going through the oslo.messaging transport.
-        """
-        kwargs = {
-            'workbook_name': workbook_name,
-            'task_name': task_name,
-            'context': context
-        }
-
-        return cls.backend.start_workflow_execution({}, **kwargs)
-
-    @classmethod
-    def mock_get_workflow_state(cls, workbook_name, execution_id):
-        """Mock the engine get_workflow_execution_state to send request
-        directly to the engine instead of going through the oslo.messaging
-        transport.
-        """
-        kwargs = {
-            'workbook_name': workbook_name,
-            'execution_id': execution_id
-        }
-
-        return cls.backend.get_workflow_execution_state({}, **kwargs)
-
-    @classmethod
-    def mock_run_task(cls, task_id, action_name, params):
-        """Mock the engine _run_tasks to send requests directly to the task
-        executor instead of going through the oslo.messaging transport.
-        """
-        exctr = executor.get_executor(cfg.CONF.engine.engine, cls.transport)
-
-        exctr.handle_task(
-            auth_context.ctx(),
-            task_id=task_id,
-            action_name=action_name,
-            params=params
-        )
-
-    @classmethod
-    def mock_handle_task(cls, cntx, **kwargs):
-        """Mock the executor handle_task to send requests directory to the task
-        executor instead of going through the oslo.messaging transport.
-        """
-        exctr = executor.get_executor(cfg.CONF.engine.engine, cls.transport)
-
-        return exctr.handle_task(cntx, **kwargs)
