@@ -23,22 +23,22 @@ from mistral import exceptions as exc
 from mistral.tests import base
 
 """
-To try against a real SNMP server:
+To try against a real SMTP server:
 
-1) set LOCAL_SMPTD = True
-   run debug snmpd on the local machine:
+1) set LOCAL_SMTPD = True
+   run debug smtpd on the local machine:
    `sudo python -m smtpd -c DebuggingServer -n localhost:25`
    Debugging server doesn't support password.
 
-2) set REMOTE_SMPT = True
-   use external SNMP (like gmail), change the configuration,
+2) set REMOTE_SMTP = True
+   use external SMTP (like gmail), change the configuration,
    provide actual username and password
-        self.settings = {
-            'host': 'smtp.gmail.com:587',
-            'from': "youraccount@gmail.com",
-            'password': "secret"
-        }
 
+   self.settings = {
+       'host': 'smtp.gmail.com:587',
+       'from': 'youraccount@gmail.com',
+       'password': 'secret'
+   }
 """
 
 LOCAL_SMTPD = False
@@ -49,79 +49,90 @@ class SendEmailActionTest(base.BaseTest):
 
     def setUp(self):
         super(SendEmailActionTest, self).setUp()
-        self.params = {
-            'to': ["dz@example.com, deg@example.com", "xyz@example.com"],
-            'subject': "Multi word subject с русскими буквами",
-            'body': "short multiline\nbody\nc русскими буквами",
-        }
-        self.settings = {
-            'smtp_server': 'mail.example.com:25',
-            'from': "bot@example.com",
-        }
-        self.to_addrs = ', '.join(self.params['to'])
+        self.to_addrs = ["dz@example.com, deg@example.com", "xyz@example.com"]
+        self.subject = "Multi word subject с русскими буквами"
+        self.body = "short multiline\nbody\nc русскими буквами"
+
+        self.smtp_server = 'mail.example.com:25'
+        self.from_addr = "bot@example.com"
+
+        self.to_addrs_str = ", ".join(self.to_addrs)
 
     @testtools.skipIf(not LOCAL_SMTPD, "Setup local smtpd to run it")
     def test_send_email_real(self):
-        action = std.SendEmailAction(self.params, self.settings)
+        action = std.SendEmailAction(
+            self.from_addr, self.to_addrs,
+            self.smtp_server, None, self.subject, self.body
+        )
         action.run()
 
     @testtools.skipIf(not REMOTE_SMTP, "Configure Remote SMTP to run it")
     def test_with_password_real(self):
-        self.params['to'] = ["dz@stackstorm.com"]
-        self.settings = {
-            'smtp_server': 'smtp.gmail.com:587',
-            'from': "username@gmail.com",
-            'password': 'secret'
-        }
+        self.to_addrs = ["dz@stackstorm.com"]
+        self.smtp_server = 'mail.example.com:25'
+        self.from_addr = "bot@example.com"
+        self.smtp_password = 'secret'
 
-        action = std.SendEmailAction(self.params, self.settings)
+        action = std.SendEmailAction(
+            self.from_addr, self.to_addrs,
+            self.smtp_server, self.smtp_password, self.subject, self.body
+        )
 
         action.run()
 
     @mock.patch('smtplib.SMTP')
     def test_send_email(self, smtp):
-        action = std.SendEmailAction(self.params, self.settings)
+        action = std.SendEmailAction(
+            self.from_addr, self.to_addrs,
+            self.smtp_server, None, self.subject, self.body
+        )
 
         action.run()
 
-        smtp.assert_called_once_with(self.settings['smtp_server'])
+        smtp.assert_called_once_with(self.smtp_server)
 
         sendmail = smtp.return_value.sendmail
 
         self.assertTrue(sendmail.called, "should call sendmail")
         self.assertEqual(
-            sendmail.call_args[1]['from_addr'], self.settings['from'])
+            self.from_addr, sendmail.call_args[1]['from_addr'])
         self.assertEqual(
-            sendmail.call_args[1]['to_addrs'], self.to_addrs)
+            self.to_addrs_str, sendmail.call_args[1]['to_addrs'])
 
         message = parser.Parser().parsestr(sendmail.call_args[1]['msg'])
 
-        self.assertEqual(self.settings['from'], message['from'])
-        self.assertEqual(self.to_addrs, message['to'])
-        self.assertEqual(self.params['subject'], message['subject'])
-        self.assertEqual(self.params['body'], message.get_payload())
+        self.assertEqual(self.from_addr, message['from'])
+        self.assertEqual(self.to_addrs_str, message['to'])
+        self.assertEqual(self.subject, message['subject'])
+        self.assertEqual(self.body, message.get_payload())
 
     @mock.patch('smtplib.SMTP')
     def test_with_password(self, smtp):
-        self.settings['password'] = "secret"
+        self.smtp_password = "secret"
 
-        action = std.SendEmailAction(self.params, self.settings)
+        action = std.SendEmailAction(
+            self.from_addr, self.to_addrs,
+            self.smtp_server, self.smtp_password, self.subject, self.body
+        )
 
         action.run()
 
         smtpmock = smtp.return_value
         calls = [mock.call.ehlo(), mock.call.starttls(), mock.call.ehlo(),
-                 mock.call.login(self.settings['from'],
-                                 self.settings['password'])]
+                 mock.call.login(self.from_addr,
+                                 self.smtp_password)]
 
         smtpmock.assert_has_calls(calls)
         self.assertTrue(smtpmock.sendmail.called, "should call sendmail")
 
     @mock.patch('mistral.actions.std_actions.LOG')
     def test_exception(self, log):
-        self.params['smtp_server'] = "wrong host"
+        self.smtp_server = "wrong host"
 
-        action = std.SendEmailAction(self.params, self.settings)
+        action = std.SendEmailAction(
+            self.from_addr, self.to_addrs,
+            self.smtp_server, None, self.subject, self.body
+        )
 
         try:
             action.run()
