@@ -12,12 +12,13 @@
 #    See the License for the specific language governing permissions and
 #    limitations under the License.
 
-from oslo.config import cfg
+from oslo_config import cfg
+from oslo_log import log as logging
 
 from mistral.db.v2 import api as db_api
-from mistral.openstack.common import log as logging
 from mistral.services import actions as action_service
 from mistral.tests import base
+from mistral import utils
 from mistral.workbook import parser as spec_parser
 
 LOG = logging.getLogger(__name__)
@@ -60,8 +61,8 @@ class ActionServiceTest(base.DbTestCase):
     def setUp(self):
         super(ActionServiceTest, self).setUp()
 
-        self.addCleanup(db_api.delete_actions, name='action1')
-        self.addCleanup(db_api.delete_actions, name='action2')
+        self.addCleanup(db_api.delete_action_definitions, name='action1')
+        self.addCleanup(db_api.delete_action_definitions, name='action2')
 
     def test_create_actions(self):
         db_actions = action_service.create_actions(ACTION_LIST)
@@ -96,7 +97,7 @@ class ActionServiceTest(base.DbTestCase):
         self.assertEqual('action1', action1_spec.get_name())
         self.assertEqual('std.echo', action1_spec.get_base())
         self.assertDictEqual({'output': 'Hi'}, action1_spec.get_base_input())
-        self.assertListEqual([], action1_spec.get_input())
+        self.assertDictEqual({}, action1_spec.get_input())
 
         db_actions = action_service.update_actions(UPDATED_ACTION_LIST)
 
@@ -108,4 +109,8 @@ class ActionServiceTest(base.DbTestCase):
         self.assertListEqual([], action1_spec.get_tags())
         self.assertEqual('std.echo', action1_spec.get_base())
         self.assertDictEqual({'output': 'Hi'}, action1_spec.get_base_input())
-        self.assertListEqual(['param1'], action1_spec.get_input())
+        self.assertIn('param1', action1_spec.get_input())
+        self.assertIs(
+            action1_spec.get_input().get('param1'),
+            utils.NotDefined
+        )
